#
# spec file for package python-pscript
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname pscript
Name:           python-pscript
Version:        0.7.7
Release:        3.2
Summary:        Python to JavaScript compiler
License:        BSD-2-Clause
URL:            https://github.com/flexxui/pscript
Source:         https://github.com/flexxui/%{modname}/archive/v%{version}/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
BuildRequires:  nodejs
# /SECTION
%python_subpackages

%description
PScript is a Python to JavaScript compiler, and is also the name of the subset
of Python that this compiler supports.

%prep
%autosetup -p1 -n %{modname}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# https://github.com/flexxui/pscript/issues/69
%pytest -k 'not test_async_and_await' pscript/tests

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/pscript
%{python_sitelib}/pscript_legacy
%{python_sitelib}/pscript-%{version}.dist-info

%changelog
* Wed Dec 11 2024 Steve Kowalik <steven.kowalik@suse.com>
- Skip a test broken by nodejs feature.
* Mon Jul 31 2023 Steve Kowalik <steven.kowalik@suse.com>
- Stop using greedy globs in %%files.
- Switch to %%pytest from invoke.
- Switch to pyproject macros.
* Tue Oct  4 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.7.7
  bump version
* Fri Dec 31 2021 Matej Cepl <mcepl@suse.com>
- Update to 0.7.6:
  - Fix for with-statement when return is used in the context.
  - Early support type hints in the code (by Jennifer Taylor).
* Thu Apr 22 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.7.5:
  * Support for Python 3.9.
  * Small docs improvements.
  * Allow to rename functions starting with an uppercase letter.
* Fri Jan 17 2020 Matej Cepl <mcepl@suse.com>
- Update to 0.7.3:
  - add examples in the wild
  - Reflect AST changes in Python 3.8.
  - use markdown for pypi long_description
- Remove python-faulthandler BR (it is optional and the package
  is Python 2-only, in Python 3 the module is in the standard
  library).
- Use tarball from GitHub, not PyPI, because the former contains
  tests.
* Fri May 24 2019 pgajdos@suse.com
- version update to 0.7.1
  * fix style error
  * Quicker op_equals
* Tue Mar 19 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.0:
  * Add ability to reduce overloading of add, mul, equals and truthy
* Tue Oct 30 2018 Jan Engelhardt <jengelh@inai.de>
- Trim history, and hypotheses from description.
* Mon Oct 29 2018 Todd R <toddrme2178@gmail.com>
- Initial version
